///
///	@file td.h @brief tower defense header file
///
///	Copyright (c) 2009 by Lutz Sammer.  All Rights Reserved.
///
///	Contributor(s):
///
///	License: AGPLv3
///
///	This program is free software: you can redistribute it and/or modify
///	it under the terms of the GNU Affero General Public License as
///	published by the Free Software Foundation, either version 3 of the
///	License.
///
///	This program is distributed in the hope that it will be useful,
///	but WITHOUT ANY WARRANTY; without even the implied warranty of
///	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
///	GNU Affero General Public License for more details.
///
///	$Id: $
//////////////////////////////////////////////////////////////////////////////

/// @addtogroup td
/// @{

//////////////////////////////////////////////////////////////////////////////
//	Prototypes
//////////////////////////////////////////////////////////////////////////////

    /// Create/destroy the tower defense window.
extern void TdCreate(const char *);

    /// Handle an expose event.
extern int TdHandleExpose(const xcb_expose_event_t *);

    /// Handle a mouse button release event.
extern int TdHandleButtonPress(const xcb_button_press_event_t *);

    /// Handle a button release event.
extern int TdHandleButtonRelease(const xcb_button_release_event_t *);
extern int TdHandleMotionNotify(const xcb_motion_notify_event_t *);

    /// Timeout for tower defense.
extern void TdTimeout(uint32_t, int, int);

    /// Initialize tower defense module.
extern void TdInit(void);

    /// Cleanup tower defense module.
extern void TdExit(void);

    /// Parse tower defense configuration.
extern void TdConfig(const Config * config);

#ifndef USE_TD

    /// Dummy for create/destroy the tower defense window.
#define TdCreate(x)

    /// Dummy for handle an expose event.
#define TdHandleExpose(x)	0
    /// Dummy for handle a mouse button release event.
#define TdHandleButtonPress(x)	0
    /// Dummy for handle a button release event.
#define TdHandleButtonRelease(x)	0

    /// Dummy for timeout for tower defense.
#define TdTimeout(x, y, z);

    /// Dummy for parse tower defense configuration.
#define TdConfig()

#endif
/// @}
